@@ -111,11 +111,11 @@ class OperationLogEntry(models.Model):
         string, properly translated.
         """
         if self.is_addition():
-            return [f"新增{self.content_type.name}"]
+            return [f"新增 {self.content_type.name}"]
         elif self.is_deletion():
-            return [f"删除{self.content_type.name}"]
+            return [f"删除 {self.content_type.name}"]
         elif not self.change_message:
-            return ["未改动"]
+            return ["未更改"]
 
         ret = []
         for field_name, (old_value, new_value) in self.change_message.items():
